//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[RegularHandPattern](index.md)/[furo](furo.md)

# furo

[common]\
open override val [furo](furo.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Furo](../../mahjongutils.models/-furo/index.md)&gt;

副露
